<!---
  CLOgmaNeo
  Copyright(c) 2022 Ogma Intelligent Systems Corp. All rights reserved.

  This copy of OgmaNeo is licensed to you under the terms described
  in the CLOGMANEO_LICENSE.md file included in this distribution.
--->

# CLOgmaNeo

[![Join the chat at https://gitter.im/ogmaneo/Lobby](https://img.shields.io/gitter/room/nwjs/nw.js.svg)](https://gitter.im/ogmaneo/Lobby)

## Introduction 

Welcome to the [Ogma](https://ogmacorp.com) CLOgmaNeo Python library. It implements SPH (Sparse Predictive Hierarchies) in a way similar to the [AOgmaNeo](https://github.com/ogmacorp/AOgmaNeo) library, but runs on accelerators using PyOpenCL.

## Requirements

- pyopencl
- h5py

## Installation

You may install from pypi:

> pip install clogmaneo

Or from this directory:

> pip install .

## Importing

The CLOgmaNeo module can be imported using:

```python
import ogmaneo
```

## Contributions

Refer to the [CONTRIBUTING.md](./CONTRIBUTING.md) file for information on making contributions to CLOgmaNeo.

## License and Copyright

<a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png" /></a><br />The work in this repository is licensed under the <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/">Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License</a>. See the  [CLOGMANEO_LICENSE.md](./CLOGMANEO_LICENSE.md) and [LICENSE.md](./LICENSE.md) file for further information.

Contact Ogma via licenses@ogmacorp.com to discuss commercial use and licensing options.

CLOgmaNeo Copyright (c) 2022 [Ogma Intelligent Systems Corp](https://ogmacorp.com). All rights reserved.
